"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Domain = void 0;
const entity_base_1 = require("./entity.base");
class Domain extends entity_base_1.Entity {
    constructor() {
        super(...arguments);
        this._domainEvents = [];
    }
    get domainEvents() {
        return this._domainEvents;
    }
    addEvent(domainEvent) {
        this._domainEvents.push(domainEvent);
    }
    clearEvents() {
        this._domainEvents = [];
    }
    async publishEvents(notifier) {
        await Promise.all(this.domainEvents.map(async (event) => {
            return notifier.notifyEvent(event.name, event.payload);
        }));
        this.clearEvents();
        for (const attr in this) {
            const attribute = this[attr];
            if (attribute instanceof Domain) {
                await attribute.publishEvents(notifier);
            }
            else if (attribute instanceof Array) {
                const prop = attribute;
                for (const nestedAttribute of prop) {
                    if (nestedAttribute instanceof Domain) {
                        await nestedAttribute.publishEvents(notifier);
                    }
                }
            }
        }
    }
}
exports.Domain = Domain;
//# sourceMappingURL=domain.base.js.map